.. include:: ../README.rst

Specification
-------------

.. automodule:: utils
   :members:
.. autoclass:: UTR.FivePrimeUTRSeq
   :members:
.. autoclass:: genome.GFGenome
   :members:
.. autoclass:: transcript.GFTranscript
   :members:
.. autoclass:: units.VCFMutator
   :members:
.. autoclass:: upstreamAUG.UpstreamAUG
   :members:

